@@ -1,9 +1,12 @@
+import js
+
+
 logging = True
 
 def log(message: str):
     global logging
     if logging:
-        print(f"pywebcanvas: {message}")
+        js.console.log(f"pywebcanvas: {message}")
 
 def disable_logging(disable: bool):
     global logging 
